@@ -424,12 +424,13 @@ class ArtellaDriveClient(object):
 
         req = Request('http://{}:{}/v2/localserve/kv/settings/workspace'.format(self._host, self._port))
         local_root = self._communicate(req)
-        if not local_root or (isinstance(local_root, dict) and 'error' in local_root):
+        if not local_root or (isinstance(local_root, dict)):
             alr = os.environ.get(consts.ALR, None)
             if alr:
                 logger.warning('Unable to get local storage root. Using env var instead: "{}"'.format(consts.ALR))
                 local_root = alr
             else:
+                local_root = ''
                 logger.error('Unable to get local storage root.')
                 logger.info(
                     'Check that the local Artella Drive service is running and you have a working internet connection.')
@@ -721,10 +722,14 @@ class ArtellaDriveClient(object):
         file_paths = utils.force_list(file_paths, remove_duplicates=True)
         result = list()
 
+        # Make sure that paths are clean
+        file_paths = [utils.clean_path(file_path) for file_path in file_paths]
+
         for file_path in file_paths:
             uri_path = path_to_uri(file_path) if not is_uri_path(file_path) else file_path
             uri_parts = urlparse(uri_path)
-            params = urlencode({'handle': uri_parts.path, 'include-remote': str(bool(include_remote)).lower()})
+            uri_handle = utils.clean_path(uri_parts.path)
+            params = urlencode({'handle': uri_handle, 'include-remote': str(bool(include_remote)).lower()})
             req = Request('http://{}:{}/v2/localserve/fileinfo?{}'.format(
                 self._host, self._port, params))
             rsp = self._communicate(req)
