@@ -18,6 +18,7 @@ import logging
 import importlib
 import subprocess
 from functools import wraps
+
 try:
     from importlib.machinery import SourceFileLoader
 except ImportError:
@@ -90,7 +91,10 @@ def clean_path(path):
         if isinstance(path, str):
             path = os.path.expanduser(path)
         else:
-            path = os.path.expanduser(str(path.encode('utf-8')))
+            try:
+                path = os.path.expanduser(str(path.encode('utf-8')))
+            except Exception:
+                path = os.path.expanduser(str(path.encode('latin1')))
     path = str(path.replace('\\', '/').replace('//', '/').rstrip('/').strip())
 
     # Fix server paths
